# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/common/proto/gateways_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.protos import clickhouse_pb2 as ydb_dot_library_dot_yql_dot_protos_dot_clickhouse__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<ydb/library/yql/providers/common/proto/gateways_config.proto\x12\x04NYql\x1a\'ydb/library/yql/protos/clickhouse.proto\"5\n\x11TActivationByHour\x12\x0c\n\x04Hour\x18\x01 \x02(\r\x12\x12\n\nPercentage\x18\x02 \x02(\r\"\xa0\x01\n\x15TActivationPercentage\x12\x15\n\nPercentage\x18\x01 \x01(\r:\x01\x30\x12\'\n\x06\x42yHour\x18\x02 \x03(\x0b\x32\x17.NYql.TActivationByHour\x12\x14\n\x0cIncludeUsers\x18\x03 \x03(\t\x12\x14\n\x0c\x45xcludeUsers\x18\x04 \x03(\t\x12\x1b\n\rExcludeRobots\x18\x05 \x01(\x08:\x04true\"U\n\x05TAttr\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\r\n\x05Value\x18\x02 \x02(\t\x12/\n\nActivation\x18\x03 \x01(\x0b\x32\x1b.NYql.TActivationPercentage\"D\n\x12TRemoteFilePattern\x12\x0f\n\x07Pattern\x18\x01 \x02(\t\x12\x0f\n\x07\x43luster\x18\x02 \x02(\t\x12\x0c\n\x04Path\x18\x03 \x02(\t\"\xab\x02\n\x12THttpGatewayConfig\x12\x18\n\x10MaxInFlightCount\x18\x01 \x01(\r\x12$\n\x1cMaxSimulatenousDownloadsSize\x18\x02 \x01(\x04\x12\x1c\n\x14\x42uffersSizePerStream\x18\x03 \x01(\r\x12 \n\x18\x43onnectionTimeoutSeconds\x18\x04 \x01(\x04\x12\x1b\n\x13\x42ytesPerSecondLimit\x18\x05 \x01(\x04\x12 \n\x18\x44ownloadBufferBytesLimit\x18\x06 \x01(\x04\x12\x1d\n\x15RequestTimeoutSeconds\x18\x07 \x01(\x04\x12\x1b\n\x13LowSpeedTimeSeconds\x18\x08 \x01(\x04\x12\x1a\n\x12LowSpeedBytesLimit\x18\t \x01(\x04\"\xab\x01\n\x10TYtClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x07YTToken\x18\x04 \x01(\t\x12\x0e\n\x06YTName\x18\x05 \x01(\t\x12 \n\x12\x45nabledYtQlQueries\x18\x06 \x01(\x08:\x04true\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\x91\x04\n\x10TYtGatewayConfig\x12\x19\n\x0eGatewayThreads\x18\x01 \x01(\r:\x01\x30\x12/\n\nYtLogLevel\x18\x02 \x01(\x0e\x32\x11.NYql.EYtLogLevel:\x08YL_ERROR\x12\x15\n\rPerfToolsPath\x18\x04 \x01(\t\x12\x1c\n\x14PerfToolsFromPackage\x18\x05 \x01(\x08\x12\x10\n\x08MrJobBin\x18\x06 \x01(\t\x12\x13\n\x0bMrJobBinMd5\x18\r \x01(\t\x12\x14\n\x0cMrJobUdfsDir\x18\x07 \x01(\t\x12#\n\x1b\x45xecuteUdfLocallyIfPossible\x18\x08 \x01(\x08\x12\x1d\n\x0eLocalChainTest\x18\t \x01(\x08:\x05\x66\x61lse\x12\x16\n\x0eYtDebugLogFile\x18\n \x01(\t\x12\x19\n\x0eYtDebugLogSize\x18\x0b \x01(\x04:\x01\x30\x12$\n\x15YtDebugLogAlwaysWrite\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\x16\n\x0eLocalChainFile\x18\x0e \x01(\t\x12\x34\n\x12RemoteFilePatterns\x18\x64 \x03(\x0b\x32\x18.NYql.TRemoteFilePattern\x12.\n\x0e\x43lusterMapping\x18\x65 \x03(\x0b\x32\x16.NYql.TYtClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x66 \x03(\x0b\x32\x0b.NYql.TAttr\"K\n\x13TYtOrmClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x15\n\x07\x45nabled\x18\x03 \x01(\x08:\x04true\"H\n\x13TYtOrmGatewayConfig\x12\x31\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x19.NYql.TYtOrmClusterConfig\"?\n\tTHostPort\x12\x0c\n\x04Host\x18\x01 \x02(\t\x12\x0c\n\x04Port\x18\x02 \x02(\r\x12\x16\n\x0eTotalTimeoutMs\x18\x03 \x01(\x04\"\x9f\x01\n\x0fTKikimrGrpcData\x12\x10\n\x08Locators\x18\x01 \x03(\t\x12\x11\n\tTimeoutMs\x18\x02 \x01(\x04\x12\x1b\n\x13MaxMessageSizeBytes\x18\x03 \x01(\x04\x12\x13\n\x0bMaxInFlight\x18\x04 \x01(\r\x12\x1f\n\x17\x45nableEndpointDiscovery\x18\x05 \x01(\x08\x12\x14\n\x0cUseLegacyApi\x18\x06 \x01(\x08\"\xb4\x02\n\x14TKikimrClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x02 \x01(\x08:\x05\x66\x61lse\x12#\n\nMessageBus\x18\x03 \x03(\x0b\x32\x0f.NYql.THostPort\x12#\n\x04Grpc\x18\x04 \x01(\x0b\x32\x15.NYql.TKikimrGrpcData\x12\x10\n\x08\x44\x61tabase\x18\x05 \x01(\t\x12\x10\n\x05TvmId\x18\x06 \x01(\r:\x01\x30\x12\r\n\x05Token\x18\x07 \x01(\t\x12\x10\n\x08ProxyUrl\x18\x08 \x01(\t\x12\x10\n\x08Location\x18\t \x01(\t\x12\x11\n\tIsFromMvp\x18\n \x01(\x08\x12#\n\tTokenType\x18\x0b \x01(\x0e\x32\x10.NYql.ETokenType\x12\x1d\n\x08Settings\x18\x65 \x03(\x0b\x32\x0b.NYql.TAttr\"p\n\x14TKikimrGatewayConfig\x12\x32\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x1a.NYql.TKikimrClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x02 \x03(\x0b\x32\x0b.NYql.TAttr\"W\n\x15TKikimrMvpProxyConfig\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x10\n\x08\x42\x61sePath\x18\x03 \x01(\t\x12\x10\n\x05TvmId\x18\x04 \x01(\r:\x01\x30\"L\n\x17TKikimrMvpGatewayConfig\x12\x31\n\x0cProxyMapping\x18\x01 \x03(\x0b\x32\x1b.NYql.TKikimrMvpProxyConfig\"\x9d\x02\n\x11TYdbClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08\x45ndpoint\x18\x02 \x01(\t\x12\r\n\x05Token\x18\x03 \x01(\t\x12#\n\x04Grpc\x18\x04 \x01(\x0b\x32\x15.NYql.TKikimrGrpcData\x12\x10\n\x05TvmId\x18\x05 \x01(\r:\x01\x30\x12\x10\n\x08\x44\x61tabase\x18\x06 \x01(\t\x12\n\n\x02Id\x18\x07 \x01(\t\x12\x0e\n\x06Secure\x18\x08 \x01(\x08\x12\x18\n\x10ServiceAccountId\x18\t \x01(\t\x12!\n\x19ServiceAccountIdSignature\x18\n \x01(\t\x12\x18\n\x10\x41\x64\x64\x42\x65\x61rerToToken\x18\x0b \x01(\x08\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\x99\x01\n\x11TYdbGatewayConfig\x12/\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x17.NYql.TYdbClusterConfig\x12\x17\n\x0f\x44\x65\x66\x61ultEndpoint\x18\x02 \x01(\t\x12\x14\n\x0c\x44\x65\x66\x61ultToken\x18\x03 \x01(\t\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x04 \x03(\x0b\x32\x0b.NYql.TAttr\"\x9d\x03\n\x18TClickHouseClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x07\x43luster\x18\x03 \x01(\t\x12\x0f\n\x07\x43HToken\x18\x04 \x01(\t\x12\x1d\n\x08Settings\x18\x65 \x03(\x0b\x32\x0b.NYql.TAttr\x12%\n\nHostScheme\x18\x05 \x01(\x0e\x32\x11.NYql.EHostScheme\x12\x10\n\x08HostPort\x18\x06 \x01(\r\x12\x1a\n\x12\x43HTokenYavSecretId\x18\x07 \x01(\t\x12\x1b\n\x13\x43HTokenYavVersionId\x18\x08 \x01(\t\x12\x15\n\rCHTokenYavKey\x18\t \x01(\t\x12\x34\n\x06Runner\x18\n \x01(\x0b\x32$.NYql.NProto.TClickHouseRunnerConfig\x12\x1c\n\x0eNativeHostPort\x18\x0b \x01(\r:\x04\x39\x30\x30\x30\x12\x1b\n\x0cNativeSecure\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\n\n\x02Id\x18\r \x01(\t\x12\x14\n\x0cGroupAllowed\x18\x0e \x03(\t\"x\n\x18TClickHouseGatewayConfig\x12\x36\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x1e.NYql.TClickHouseClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x02 \x03(\x0b\x32\x0b.NYql.TAttr\"[\n\x0fTYfArtifactLink\x12#\n\x04Type\x18\x01 \x01(\x0e\x32\x15.NYql.EYfArtifactType\x12\x0b\n\x03Url\x18\x02 \x01(\t\x12\x16\n\x0eTargetFilePath\x18\x03 \x01(\t\"k\n\x1bTRtmrOperationArtifactsInfo\x12&\n\x04Type\x18\x01 \x01(\x0e\x32\x18.NYql.ERtmrOperationType\x12$\n\x05Links\x18\x02 \x03(\x0b\x32\x15.NYql.TYfArtifactLink\"8\n\x13TRtmrPqConsumerInfo\x12\x0f\n\x07\x43luster\x18\x01 \x01(\t\x12\x10\n\x08\x43onsumer\x18\x02 \x01(\t\"\xf2\x03\n\x12TRtmrClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x07\x43luster\x18\x03 \x01(\t\x12\x12\n\nRemoteName\x18\x04 \x01(\t\x12\x11\n\tYfCluster\x18\x05 \x01(\t\x12\x13\n\x0bS3TokenPath\x18\x06 \x01(\t\x12\x17\n\x0fS3FileCachePath\x18\x07 \x01(\t\x12\x10\n\x05TvmId\x18\x08 \x01(\r:\x01\x30\x12\x15\n\rTvmSecretPath\x18\t \x01(\t\x12\r\n\x05Users\x18\n \x03(\t\x12 \n\x11UploadViaYfClient\x18\x0b \x01(\x08:\x05\x66\x61lse\x12\x15\n\rMdsTorrentUrl\x18\x0c \x01(\t\x12<\n\x11\x41rtifactOverrides\x18\r \x03(\x0b\x32!.NYql.TRtmrOperationArtifactsInfo\x12\x12\n\nPqConsumer\x18\x0e \x01(\t\x12\x34\n\x11PqConsumerMapping\x18\x0f \x03(\x0b\x32\x19.NYql.TRtmrPqConsumerInfo\x12\x17\n\x0fMaxPqPartitions\x18\x10 \x01(\r\x12\x1f\n\x17PreviewCollectTimeoutMs\x18\x11 \x01(\r\x12\x1d\n\x08Settings\x18\x65 \x03(\x0b\x32\x0b.NYql.TAttr\"\xd8\x02\n\x12TRtmrGatewayConfig\x12\x30\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x18.NYql.TRtmrClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x02 \x03(\x0b\x32\x0b.NYql.TAttr\x12\x15\n\rYqlRtmrDynLib\x18\x03 \x01(\t\x12\x1e\n\x0fUseFakeYfUpload\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x11\n\tArtifacts\x18\x05 \x03(\t\x12:\n\x0f\x43ommonArtifacts\x18\x06 \x03(\x0b\x32!.NYql.TRtmrOperationArtifactsInfo\x12\x1b\n\x0fMaxPqPartitions\x18\x07 \x01(\r:\x02\x31\x30\x12%\n\x17PreviewCollectTimeoutMs\x18\x08 \x01(\r:\x04\x32\x30\x30\x30\x12 \n\x11KeepActiveProcess\x18\t \x01(\x08:\x05\x66\x61lse\"\xba\x03\n\x10TPqClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12G\n\x0b\x43lusterType\x18\x02 \x01(\x0e\x32#.NYql.TPqClusterConfig.EClusterType:\rCT_PERS_QUEUE\x12\x10\n\x08\x45ndpoint\x18\x03 \x01(\t\x12\x1d\n\x15\x43onfigManagerEndpoint\x18\x04 \x01(\t\x12\r\n\x05Token\x18\x05 \x01(\t\x12\x17\n\x08\x44\x61tabase\x18\x06 \x01(\t:\x05/Root\x12\x10\n\x05TvmId\x18\x07 \x01(\r:\x01\x30\x12\x0e\n\x06UseSsl\x18\x08 \x01(\x08\x12\x18\n\x10ServiceAccountId\x18\t \x01(\t\x12!\n\x19ServiceAccountIdSignature\x18\n \x01(\t\x12\x18\n\x10\x41\x64\x64\x42\x65\x61rerToToken\x18\x0b \x01(\x08\x12\x12\n\nDatabaseId\x18\x0c \x01(\t\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"J\n\x0c\x45\x43lusterType\x12\x12\n\x0e\x43T_UNSPECIFIED\x10\x00\x12\x11\n\rCT_PERS_QUEUE\x10\x01\x12\x13\n\x0f\x43T_DATA_STREAMS\x10\x02\"~\n\x10TPqGatewayConfig\x12.\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x16.NYql.TPqClusterConfig\x12\x14\n\x0c\x44\x65\x66\x61ultToken\x18\x02 \x01(\t\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\x8f\x01\n\x12TStatClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x11\n\tStatToken\x18\x04 \x01(\t\x12\x10\n\x08StatName\x18\x05 \x01(\t\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\x87\x01\n\x12TStatGatewayConfig\x12\x19\n\x0eGatewayThreads\x18\x01 \x01(\r:\x01\x30\x12\x30\n\x0e\x43lusterMapping\x18\x65 \x03(\x0b\x32\x18.NYql.TStatClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x66 \x03(\x0b\x32\x0b.NYql.TAttr\"5\n\x12TChytClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x11\n\tYtCluster\x18\x02 \x01(\t\"F\n\x12TChytGatewayConfig\x12\x30\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x18.NYql.TChytClusterConfig\"\x98\x01\n\x10TS3ClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0b\n\x03Url\x18\x02 \x01(\t\x12\r\n\x05Token\x18\x03 \x01(\t\x12\x18\n\x10ServiceAccountId\x18\x04 \x01(\t\x12!\n\x19ServiceAccountIdSignature\x18\x05 \x01(\t\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"9\n\x12TS3FormatSizeLimit\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x15\n\rFileSizeLimit\x18\x02 \x01(\x04\"\xae\x02\n\x10TS3GatewayConfig\x12.\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x16.NYql.TS3ClusterConfig\x12\x15\n\rFileSizeLimit\x18\x02 \x01(\x04\x12\x31\n\x0f\x46ormatSizeLimit\x18\x06 \x03(\x0b\x32\x18.NYql.TS3FormatSizeLimit\x12\x18\n\x10MaxFilesPerQuery\x18\x03 \x01(\x04\x12\x1b\n\x13MaxReadSizePerQuery\x18\x04 \x01(\x04\x12!\n\x19MaxDiscoveryFilesPerQuery\x18\x05 \x01(\x04\x12 \n\x18MaxInflightListsPerQuery\x18\x07 \x01(\x04\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\xbb\x03\n\x15TSolomonClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x0e\n\x06UseSsl\x18\x03 \x01(\x08\x12Q\n\x0b\x43lusterType\x18\x04 \x01(\x0e\x32/.NYql.TSolomonClusterConfig.ESolomonClusterType:\x0bSCT_SOLOMON\x12\r\n\x05Token\x18\x05 \x01(\t\x12\x18\n\x10ServiceAccountId\x18\x06 \x01(\t\x12!\n\x19ServiceAccountIdSignature\x18\x07 \x01(\t\x12\x34\n\x04Path\x18\x08 \x01(\x0b\x32&.NYql.TSolomonClusterConfig.TShardPath\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\x1a.\n\nTShardPath\x12\x0f\n\x07Project\x18\x01 \x02(\t\x12\x0f\n\x07\x43luster\x18\x02 \x02(\t\"O\n\x13\x45SolomonClusterType\x12\x13\n\x0fSCT_UNSPECIFIED\x10\x00\x12\x0f\n\x0bSCT_SOLOMON\x10\x01\x12\x12\n\x0eSCT_MONITORING\x10\x02\"r\n\x15TSolomonGatewayConfig\x12\x33\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x1b.NYql.TSolomonClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x02 \x03(\x0b\x32\x0b.NYql.TAttr\"\xe3\x02\n\x1cTFileStorageAdditionalConfig\x12\x43\n\x0b\x41llowedUrls\x18\x02 \x03(\x0b\x32..NYql.TFileStorageAdditionalConfig.TUrlPattern\x12K\n\x13\x45xternalAllowedUrls\x18\x03 \x03(\x0b\x32..NYql.TFileStorageAdditionalConfig.TUrlPattern\x12J\n\rCustomSchemes\x18\x04 \x03(\x0b\x32\x33.NYql.TFileStorageAdditionalConfig.TSchemeTranslate\x1a-\n\x0bTUrlPattern\x12\x0f\n\x07Pattern\x18\x01 \x02(\t\x12\r\n\x05\x41lias\x18\x02 \x01(\t\x1a\x36\n\x10TSchemeTranslate\x12\x0f\n\x07Pattern\x18\x01 \x02(\t\x12\x11\n\tTargetUrl\x18\x02 \x02(\t\"d\n\x18TPostgresqlClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x0f\n\x07PGtoken\x18\x03 \x01(\t\x12\x18\n\x10TargetServerType\x18\x04 \x01(\t\"R\n\x18TPostgresqlGatewayConfig\x12\x36\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x1e.NYql.TPostgresqlClusterConfig\"H\n\x13TMysqlClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x12\n\nMysqlToken\x18\x03 \x01(\t\"H\n\x13TMysqlGatewayConfig\x12\x31\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x19.NYql.TMysqlClusterConfig\"\xda\x03\n\x10TDqGatewayConfig\x12 \n\x15\x44\x65\x66\x61ultAutoPercentage\x18\x01 \x01(\r:\x01\x30\x12N\n\x11\x44\x65\x66\x61ultAutoByHour\x18\x02 \x03(\x0b\x32\x33.NYql.TDqGatewayConfig.TDefaultAutoByHourPercentage\x12\x1d\n\x15NoDefaultAutoForUsers\x18\x03 \x03(\t\x12#\n\x1b\x44\x65\x66\x61ultAnalyzeQueryForUsers\x18\x04 \x03(\t\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x66 \x03(\x0b\x32\x0b.NYql.TAttr\x12\x1f\n\x14WithHiddenPercentage\x18\x05 \x01(\r:\x01\x30\x12M\n\x10WithHiddenByHour\x18\x06 \x03(\x0b\x32\x33.NYql.TDqGatewayConfig.TDefaultAutoByHourPercentage\x12\x1c\n\x14NoWithHiddenForUsers\x18\x07 \x03(\t\x12\x1a\n\x12WithHiddenForUsers\x18\x08 \x03(\t\x1a@\n\x1cTDefaultAutoByHourPercentage\x12\x0c\n\x04Hour\x18\x01 \x02(\r\x12\x12\n\nPercentage\x18\x02 \x02(\r\"X\n\tTCoreAttr\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\x0c\n\x04\x41rgs\x18\x02 \x03(\t\x12/\n\nActivation\x18\x03 \x01(\x0b\x32\x1b.NYql.TActivationPercentage\"0\n\x0eTYqlCoreConfig\x12\x1e\n\x05\x46lags\x18\x01 \x03(\x0b\x32\x0f.NYql.TCoreAttr\"@\n\x1cTWarnAsErrorByHourPercentage\x12\x0c\n\x04Hour\x18\x01 \x02(\r\x12\x12\n\nPercentage\x18\x02 \x02(\r\"\xbc\x01\n\x0eTSqlCoreConfig\x12(\n\x1dV0SyntaxWarnAsErrorPercentage\x18\x01 \x01(\r:\x01\x30\x12\x45\n\x19V0SyntaxWarnAsErrorByHour\x18\x02 \x03(\x0b\x32\".NYql.TWarnAsErrorByHourPercentage\x12\x1f\n\x17NoV0SyntaxErrorForUsers\x18\x03 \x03(\t\x12\x18\n\x10TranslationFlags\x18\x04 \x03(\t\"\xb4\x06\n\x0fTGatewaysConfig\x12\"\n\x02Yt\x18\x01 \x01(\x0b\x32\x16.NYql.TYtGatewayConfig\x12*\n\x06Kikimr\x18\x02 \x01(\x0b\x32\x1a.NYql.TKikimrGatewayConfig\x12\x32\n\nClickHouse\x18\x03 \x01(\x0b\x32\x1e.NYql.TClickHouseGatewayConfig\x12&\n\x04Rtmr\x18\x04 \x01(\x0b\x32\x18.NYql.TRtmrGatewayConfig\x12\x30\n\tKikimrMvp\x18\x05 \x01(\x0b\x32\x1d.NYql.TKikimrMvpGatewayConfig\x12&\n\x04Stat\x18\x06 \x01(\x0b\x32\x18.NYql.TStatGatewayConfig\x12&\n\x04\x43hyt\x18\x07 \x01(\x0b\x32\x18.NYql.TChytGatewayConfig\x12,\n\x07Solomon\x18\x08 \x01(\x0b\x32\x1b.NYql.TSolomonGatewayConfig\x12.\n\x02\x46s\x18\t \x01(\x0b\x32\".NYql.TFileStorageAdditionalConfig\x12%\n\x07YqlCore\x18\n \x01(\x0b\x32\x14.NYql.TYqlCoreConfig\x12\x32\n\nPostgresql\x18\x0b \x01(\x0b\x32\x1e.NYql.TPostgresqlGatewayConfig\x12%\n\x07SqlCore\x18\x0c \x01(\x0b\x32\x14.NYql.TSqlCoreConfig\x12\"\n\x02\x44q\x18\r \x01(\x0b\x32\x16.NYql.TDqGatewayConfig\x12(\n\x05Mysql\x18\x0e \x01(\x0b\x32\x19.NYql.TMysqlGatewayConfig\x12$\n\x03Ydb\x18\x0f \x01(\x0b\x32\x17.NYql.TYdbGatewayConfig\x12\"\n\x02Pq\x18\x10 \x01(\x0b\x32\x16.NYql.TPqGatewayConfig\x12\"\n\x02S3\x18\x11 \x01(\x0b\x32\x16.NYql.TS3GatewayConfig\x12-\n\x0bHttpGateway\x18\x12 \x01(\x0b\x32\x18.NYql.THttpGatewayConfig\x12(\n\x05YtOrm\x18\x13 \x01(\x0b\x32\x19.NYql.TYtOrmGatewayConfig*Z\n\x0b\x45YtLogLevel\x12\x14\n\x07YL_NONE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x0c\n\x08YL_FATAL\x10\x00\x12\x0c\n\x08YL_ERROR\x10\x01\x12\x0b\n\x07YL_INFO\x10\x02\x12\x0c\n\x08YL_DEBUG\x10\x03*(\n\x0b\x45HostScheme\x12\x0b\n\x07HS_HTTP\x10\x00\x12\x0c\n\x08HS_HTTPS\x10\x01*?\n\nETokenType\x12\x07\n\x03IAM\x10\x00\x12\t\n\x05OAUTH\x10\x01\x12\x0c\n\x08\x42LACKBOX\x10\x02\x12\x0f\n\x0b\x43REDENTIALS\x10\x03*9\n\x0f\x45YfArtifactType\x12\x0b\n\x07\x41T_NONE\x10\x00\x12\x0b\n\x07\x41T_FILE\x10\x01\x12\x0c\n\x08\x41T_LAYER\x10\x02*e\n\x12\x45RtmrOperationType\x12\x0b\n\x07OT_NONE\x10\x00\x12\x0f\n\x0bOT_LF_PARSE\x10\x01\x12\x0e\n\nOT_YDB_OUT\x10\x02\x12\x12\n\x0eOT_SOLOMON_OUT\x10\x03\x12\r\n\tOT_PQ_OUT\x10\x04\x42\x15\n\x13ru.yandex.yql.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.common.proto.gateways_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ru.yandex.yql.proto'
  _EYTLOGLEVEL._serialized_start=9008
  _EYTLOGLEVEL._serialized_end=9098
  _EHOSTSCHEME._serialized_start=9100
  _EHOSTSCHEME._serialized_end=9140
  _ETOKENTYPE._serialized_start=9142
  _ETOKENTYPE._serialized_end=9205
  _EYFARTIFACTTYPE._serialized_start=9207
  _EYFARTIFACTTYPE._serialized_end=9264
  _ERTMROPERATIONTYPE._serialized_start=9266
  _ERTMROPERATIONTYPE._serialized_end=9367
  _TACTIVATIONBYHOUR._serialized_start=111
  _TACTIVATIONBYHOUR._serialized_end=164
  _TACTIVATIONPERCENTAGE._serialized_start=167
  _TACTIVATIONPERCENTAGE._serialized_end=327
  _TATTR._serialized_start=329
  _TATTR._serialized_end=414
  _TREMOTEFILEPATTERN._serialized_start=416
  _TREMOTEFILEPATTERN._serialized_end=484
  _THTTPGATEWAYCONFIG._serialized_start=487
  _THTTPGATEWAYCONFIG._serialized_end=786
  _TYTCLUSTERCONFIG._serialized_start=789
  _TYTCLUSTERCONFIG._serialized_end=960
  _TYTGATEWAYCONFIG._serialized_start=963
  _TYTGATEWAYCONFIG._serialized_end=1492
  _TYTORMCLUSTERCONFIG._serialized_start=1494
  _TYTORMCLUSTERCONFIG._serialized_end=1569
  _TYTORMGATEWAYCONFIG._serialized_start=1571
  _TYTORMGATEWAYCONFIG._serialized_end=1643
  _THOSTPORT._serialized_start=1645
  _THOSTPORT._serialized_end=1708
  _TKIKIMRGRPCDATA._serialized_start=1711
  _TKIKIMRGRPCDATA._serialized_end=1870
  _TKIKIMRCLUSTERCONFIG._serialized_start=1873
  _TKIKIMRCLUSTERCONFIG._serialized_end=2181
  _TKIKIMRGATEWAYCONFIG._serialized_start=2183
  _TKIKIMRGATEWAYCONFIG._serialized_end=2295
  _TKIKIMRMVPPROXYCONFIG._serialized_start=2297
  _TKIKIMRMVPPROXYCONFIG._serialized_end=2384
  _TKIKIMRMVPGATEWAYCONFIG._serialized_start=2386
  _TKIKIMRMVPGATEWAYCONFIG._serialized_end=2462
  _TYDBCLUSTERCONFIG._serialized_start=2465
  _TYDBCLUSTERCONFIG._serialized_end=2750
  _TYDBGATEWAYCONFIG._serialized_start=2753
  _TYDBGATEWAYCONFIG._serialized_end=2906
  _TCLICKHOUSECLUSTERCONFIG._serialized_start=2909
  _TCLICKHOUSECLUSTERCONFIG._serialized_end=3322
  _TCLICKHOUSEGATEWAYCONFIG._serialized_start=3324
  _TCLICKHOUSEGATEWAYCONFIG._serialized_end=3444
  _TYFARTIFACTLINK._serialized_start=3446
  _TYFARTIFACTLINK._serialized_end=3537
  _TRTMROPERATIONARTIFACTSINFO._serialized_start=3539
  _TRTMROPERATIONARTIFACTSINFO._serialized_end=3646
  _TRTMRPQCONSUMERINFO._serialized_start=3648
  _TRTMRPQCONSUMERINFO._serialized_end=3704
  _TRTMRCLUSTERCONFIG._serialized_start=3707
  _TRTMRCLUSTERCONFIG._serialized_end=4205
  _TRTMRGATEWAYCONFIG._serialized_start=4208
  _TRTMRGATEWAYCONFIG._serialized_end=4552
  _TPQCLUSTERCONFIG._serialized_start=4555
  _TPQCLUSTERCONFIG._serialized_end=4997
  _TPQCLUSTERCONFIG_ECLUSTERTYPE._serialized_start=4923
  _TPQCLUSTERCONFIG_ECLUSTERTYPE._serialized_end=4997
  _TPQGATEWAYCONFIG._serialized_start=4999
  _TPQGATEWAYCONFIG._serialized_end=5125
  _TSTATCLUSTERCONFIG._serialized_start=5128
  _TSTATCLUSTERCONFIG._serialized_end=5271
  _TSTATGATEWAYCONFIG._serialized_start=5274
  _TSTATGATEWAYCONFIG._serialized_end=5409
  _TCHYTCLUSTERCONFIG._serialized_start=5411
  _TCHYTCLUSTERCONFIG._serialized_end=5464
  _TCHYTGATEWAYCONFIG._serialized_start=5466
  _TCHYTGATEWAYCONFIG._serialized_end=5536
  _TS3CLUSTERCONFIG._serialized_start=5539
  _TS3CLUSTERCONFIG._serialized_end=5691
  _TS3FORMATSIZELIMIT._serialized_start=5693
  _TS3FORMATSIZELIMIT._serialized_end=5750
  _TS3GATEWAYCONFIG._serialized_start=5753
  _TS3GATEWAYCONFIG._serialized_end=6055
  _TSOLOMONCLUSTERCONFIG._serialized_start=6058
  _TSOLOMONCLUSTERCONFIG._serialized_end=6501
  _TSOLOMONCLUSTERCONFIG_TSHARDPATH._serialized_start=6374
  _TSOLOMONCLUSTERCONFIG_TSHARDPATH._serialized_end=6420
  _TSOLOMONCLUSTERCONFIG_ESOLOMONCLUSTERTYPE._serialized_start=6422
  _TSOLOMONCLUSTERCONFIG_ESOLOMONCLUSTERTYPE._serialized_end=6501
  _TSOLOMONGATEWAYCONFIG._serialized_start=6503
  _TSOLOMONGATEWAYCONFIG._serialized_end=6617
  _TFILESTORAGEADDITIONALCONFIG._serialized_start=6620
  _TFILESTORAGEADDITIONALCONFIG._serialized_end=6975
  _TFILESTORAGEADDITIONALCONFIG_TURLPATTERN._serialized_start=6874
  _TFILESTORAGEADDITIONALCONFIG_TURLPATTERN._serialized_end=6919
  _TFILESTORAGEADDITIONALCONFIG_TSCHEMETRANSLATE._serialized_start=6921
  _TFILESTORAGEADDITIONALCONFIG_TSCHEMETRANSLATE._serialized_end=6975
  _TPOSTGRESQLCLUSTERCONFIG._serialized_start=6977
  _TPOSTGRESQLCLUSTERCONFIG._serialized_end=7077
  _TPOSTGRESQLGATEWAYCONFIG._serialized_start=7079
  _TPOSTGRESQLGATEWAYCONFIG._serialized_end=7161
  _TMYSQLCLUSTERCONFIG._serialized_start=7163
  _TMYSQLCLUSTERCONFIG._serialized_end=7235
  _TMYSQLGATEWAYCONFIG._serialized_start=7237
  _TMYSQLGATEWAYCONFIG._serialized_end=7309
  _TDQGATEWAYCONFIG._serialized_start=7312
  _TDQGATEWAYCONFIG._serialized_end=7786
  _TDQGATEWAYCONFIG_TDEFAULTAUTOBYHOURPERCENTAGE._serialized_start=7722
  _TDQGATEWAYCONFIG_TDEFAULTAUTOBYHOURPERCENTAGE._serialized_end=7786
  _TCOREATTR._serialized_start=7788
  _TCOREATTR._serialized_end=7876
  _TYQLCORECONFIG._serialized_start=7878
  _TYQLCORECONFIG._serialized_end=7926
  _TWARNASERRORBYHOURPERCENTAGE._serialized_start=7928
  _TWARNASERRORBYHOURPERCENTAGE._serialized_end=7992
  _TSQLCORECONFIG._serialized_start=7995
  _TSQLCORECONFIG._serialized_end=8183
  _TGATEWAYSCONFIG._serialized_start=8186
  _TGATEWAYSCONFIG._serialized_end=9006
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_scheme.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fydb/core/protos/tx_scheme.proto\x12\x0fNKikimrTxScheme\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a/ydb/core/protos/bind_channel_storage_pool.proto\"1\n\rTSchemeConfig\x12 \n\x18PipeClientCachePoolLimit\x18\x01 \x01(\x04\"|\n\x07TConfig\x12/\n\x07\x43urrent\x18\x01 \x01(\x0b\x32\x1e.NKikimrTxScheme.TSchemeConfig\x12@\n\x18\x44\x65\x66\x61ultSchemeShardConfig\x18\x03 \x01(\x0b\x32\x1e.NKikimrTxScheme.TSchemeConfig\"\x8f\x01\n\x11TEvNavigateScheme\x12\x0c\n\x04Path\x18\x01 \x01(\x0c\x12\x10\n\x08TextPath\x18\x02 \x01(\x0c\x12\x1e\n\x16ReadMaterializedFamily\x18\x03 \x01(\r\x12\x1a\n\x0cShowFamilies\x18\x04 \x01(\x08:\x04true\x12\x1e\n\x10ShowChildrenTags\x18\x05 \x01(\x08:\x04true\"\xbb\x01\n\x15TEvNavigateSchemePart\x12\x0c\n\x04Path\x18\x01 \x01(\x0c\x12\x10\n\x08TextPath\x18\x02 \x01(\x0c\x12\x1e\n\x16ReadMaterializedFamily\x18\x03 \x01(\r\x12&\n\x06Source\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x1a\n\x0cShowFamilies\x18\x05 \x01(\x08:\x04true\x12\x1e\n\x10ShowChildrenTags\x18\x06 \x01(\x08:\x04true\"h\n\x1bTEvNavigateSchemePartResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0f\n\x07ShardId\x18\x02 \x01(\x04\x12\x14\n\x0cSchemePrefix\x18\x03 \x01(\x0c\x12\x12\n\nSchemePart\x18\x04 \x01(\x0c\"\xd1\x01\n\x10TEvInitRootShard\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0f\n\x07RootTag\x18\x02 \x01(\r\x12\x13\n\x0bRootTagName\x18\x03 \x01(\x0c\x12(\n\x06\x43onfig\x18\x04 \x01(\x0b\x32\x18.NKikimrTxScheme.TConfig\x12\r\n\x05Owner\x18\x05 \x01(\t\x12\x36\n\x0cStoragePools\x18\x06 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\"8\n\x16TEvInitRootShardResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0e\n\x06Status\x18\x02 \x01(\r\"c\n\x0fTEvUpdateConfig\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x18.NKikimrTxScheme.TConfig\"c\n\x15TEvUpdateConfigResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Reason\x18\x03 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_scheme_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSCHEMECONFIG._serialized_start=169
  _TSCHEMECONFIG._serialized_end=218
  _TCONFIG._serialized_start=220
  _TCONFIG._serialized_end=344
  _TEVNAVIGATESCHEME._serialized_start=347
  _TEVNAVIGATESCHEME._serialized_end=490
  _TEVNAVIGATESCHEMEPART._serialized_start=493
  _TEVNAVIGATESCHEMEPART._serialized_end=680
  _TEVNAVIGATESCHEMEPARTRESULT._serialized_start=682
  _TEVNAVIGATESCHEMEPARTRESULT._serialized_end=786
  _TEVINITROOTSHARD._serialized_start=789
  _TEVINITROOTSHARD._serialized_end=998
  _TEVINITROOTSHARDRESULT._serialized_start=1000
  _TEVINITROOTSHARDRESULT._serialized_end=1056
  _TEVUPDATECONFIG._serialized_start=1058
  _TEVUPDATECONFIG._serialized_end=1157
  _TEVUPDATECONFIGRESULT._serialized_start=1159
  _TEVUPDATECONFIGRESULT._serialized_end=1258
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/checkpoint_coordinator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.yq.libs.config.protos import storage_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ydb/core/yq/libs/config/protos/checkpoint_coordinator.proto\x12\x0bNYq.NConfig\x1a,ydb/core/yq/libs/config/protos/storage.proto\"`\n\x19TStateStorageLimitsConfig\x12$\n\x1cMaxGraphCheckpointsSizeBytes\x18\x01 \x01(\x04\x12\x1d\n\x15MaxTaskStateSizeBytes\x18\x02 \x01(\x04\"&\n\x13TCheckpointGcConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\"\x9f\x02\n\x1cTCheckpointCoordinatorConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12/\n\x07Storage\x18\x02 \x01(\x0b\x32\x1e.NYq.NConfig.TYdbStorageConfig\x12\x41\n\x17\x43heckpointGarbageConfig\x18\x03 \x01(\x0b\x32 .NYq.NConfig.TCheckpointGcConfig\x12\x42\n\x12StateStorageLimits\x18\x04 \x01(\x0b\x32&.NYq.NConfig.TStateStorageLimitsConfig\x12!\n\x19\x43heckpointingPeriodMillis\x18\x05 \x01(\x04\x12\x13\n\x0bMaxInflight\x18\x06 \x01(\x04\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.checkpoint_coordinator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TSTATESTORAGELIMITSCONFIG._serialized_start=122
  _TSTATESTORAGELIMITSCONFIG._serialized_end=218
  _TCHECKPOINTGCCONFIG._serialized_start=220
  _TCHECKPOINTGCCONFIG._serialized_end=258
  _TCHECKPOINTCOORDINATORCONFIG._serialized_start=261
  _TCHECKPOINTCOORDINATORCONFIG._serialized_end=548
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/public/issue/protos/issue_severity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8ydb/library/yql/public/issue/protos/issue_severity.proto\x12\x04NYql\"R\n\x0cTSeverityIds\"B\n\x0b\x45SeverityId\x12\x0b\n\x07S_FATAL\x10\x00\x12\x0b\n\x07S_ERROR\x10\x01\x12\r\n\tS_WARNING\x10\x02\x12\n\n\x06S_INFO\x10\x03\x42\x16\n\x14\x63om.yandex.yql.protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.public.issue.protos.issue_severity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.yandex.yql.proto'
  _TSEVERITYIDS._serialized_start=66
  _TSEVERITYIDS._serialized_end=148
  _TSEVERITYIDS_ESEVERITYID._serialized_start=82
  _TSEVERITYIDS_ESEVERITYID._serialized_end=148
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/yq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos.annotations import sensitive_pb2 as ydb_dot_public_dot_api_dot_protos_dot_annotations_dot_sensitive__pb2
from ydb.public.api.protos.annotations import validation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_annotations_dot_validation__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/public/api/protos/yq.proto\x12\x0bYandexQuery\x1a\x31ydb/public/api/protos/annotations/sensitive.proto\x1a\x32ydb/public/api/protos/annotations/validation.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a%ydb/public/api/protos/ydb_value.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"x\n\x03\x41\x63l\x12/\n\nvisibility\x18\x01 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\"@\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\t\n\x05SCOPE\x10\x02\"\x83\x03\n\x06Limits\x12!\n\x0fvcpu_rate_limit\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0f\x66low_rate_limit\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fvcpu_time_limit\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fmax_result_size\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fmax_result_rows\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1e\n\x0cmemory_limit\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12-\n\nresult_ttl\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x11\x65xecution_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x38\n\x12\x65xecution_deadline\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x42\t\n\x07timeout\"\xe6\x03\n\x14StreamingDisposition\x12(\n\x06oldest\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\'\n\x05\x66resh\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12?\n\tfrom_time\x18\x03 \x01(\x0b\x32*.YandexQuery.StreamingDisposition.FromTimeH\x00\x12=\n\x08time_ago\x18\x04 \x01(\x0b\x32).YandexQuery.StreamingDisposition.TimeAgoH\x00\x12T\n\x14\x66rom_last_checkpoint\x18\x05 \x01(\x0b\x32\x34.YandexQuery.StreamingDisposition.FromLastCheckpointH\x00\x1a\x39\n\x08\x46romTime\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x36\n\x07TimeAgo\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a#\n\x12\x46romLastCheckpoint\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\x42\r\n\x0b\x64isposition\"\xc1\x04\n\x0cQueryContent\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.YandexQuery.QueryContent.QueryType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1d\n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x10.YandexQuery.Acl\x12#\n\x06limits\x18\x04 \x01(\x0b\x32\x13.YandexQuery.Limits\x12\x16\n\x04text\x18\x05 \x01(\tB\x08\xa2\xe6*\x04\x18\x80\xa0\x06\x12\x11\n\tautomatic\x18\x06 \x01(\x08\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\x12\x61\n\x12\x65xecution_settings\x18\n \x03(\x0b\x32\x30.YandexQuery.QueryContent.ExecutionSettingsEntryB\x13\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x03\x18\x80 \x12\x35\n\x06syntax\x18\x0b \x01(\x0e\x32%.YandexQuery.QueryContent.QuerySyntax\x1a\x38\n\x16\x45xecutionSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\tQueryType\x12\x1a\n\x16QUERY_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tANALYTICS\x10\x01\x12\r\n\tSTREAMING\x10\x02\"?\n\x0bQuerySyntax\x12\x1c\n\x18QUERY_SYNTAX_UNSPECIFIED\x10\x00\x12\n\n\x06YQL_V1\x10\x01\x12\x06\n\x02PG\x10\x02\"\xe5\x01\n\nCommonMeta\x12\x17\n\x02id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x1f\n\ncreated_by\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12 \n\x0bmodified_by\x18\x03 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x08revision\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xb6\x06\n\tQueryMeta\x12\'\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\x12\x30\n\x0csubmitted_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x0c\x65xecute_mode\x18\x04 \x01(\x0e\x32\x18.YandexQuery.ExecuteMode\x12\x34\n\x06status\x18\x05 \x01(\x0e\x32$.YandexQuery.QueryMeta.ComputeStatus\x12\x1f\n\x17last_job_query_revision\x18\x06 \x01(\x03\x12\x13\n\x0blast_job_id\x18\x07 \x01(\t\x12-\n\texpire_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10result_expire_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nstarted_by\x18\n \x01(\t\x12\x14\n\naborted_by\x18\x0b \x01(\tH\x00\x12\x13\n\tpaused_by\x18\x0c \x01(\tH\x00\x12\x1d\n\x15has_saved_checkpoints\x18\r \x01(\x08\"\x83\x02\n\rComputeStatus\x12\x1e\n\x1a\x43OMPUTE_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\x13\n\x0f\x41\x42ORTED_BY_USER\x10\x02\x12\x15\n\x11\x41\x42ORTED_BY_SYSTEM\x10\x03\x12\x14\n\x10\x41\x42ORTING_BY_USER\x10\x04\x12\x16\n\x12\x41\x42ORTING_BY_SYSTEM\x10\x05\x12\x0c\n\x08RESUMING\x10\x06\x12\x0b\n\x07RUNNING\x10\x07\x12\r\n\tCOMPLETED\x10\x08\x12\x0e\n\nCOMPLETING\x10\x0c\x12\n\n\x06\x46\x41ILED\x10\t\x12\x0b\n\x07\x46\x41ILING\x10\r\x12\n\n\x06PAUSED\x10\x0b\x12\x0b\n\x07PAUSING\x10\nB\x08\n\x06\x61\x63tion\"\xc0\x01\n\nBriefQuery\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.YandexQuery.QueryContent.QueryType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12$\n\x04meta\x18\x03 \x01(\x0b\x32\x16.YandexQuery.QueryMeta\x12/\n\nvisibility\x18\x04 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\x12\x11\n\tautomatic\x18\x05 \x01(\x08\"\x19\n\tQueryPlan\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x18\n\x08QueryAst\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"]\n\rResultSetMeta\x12\x1b\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x0b.Ydb.Column\x12\x1c\n\nrows_count\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x11\n\ttruncated\x18\x03 \x01(\x08\"\xe4\x02\n\x05Query\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.YandexQuery.QueryMeta\x12*\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x19.YandexQuery.QueryContent\x12$\n\x04plan\x18\x03 \x01(\x0b\x32\x16.YandexQuery.QueryPlan\x12&\n\x05issue\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\x0ftransient_issue\x18\x05 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\nstatistics\x18\x06 \x01(\x0b\x32\x1c.YandexQuery.QueryStatistics\x12\x33\n\x0fresult_set_meta\x18\x07 \x03(\x0b\x32\x1a.YandexQuery.ResultSetMeta\x12\"\n\x03\x61st\x18\x08 \x01(\x0b\x32\x15.YandexQuery.QueryAst\"\x1f\n\x0fQueryStatistics\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x85\x02\n\x12\x43reateQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12*\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x19.YandexQuery.QueryContent\x12.\n\x0c\x65xecute_mode\x18\x03 \x01(\x0e\x32\x18.YandexQuery.ExecuteMode\x12\x36\n\x0b\x64isposition\x18\x04 \x01(\x0b\x32!.YandexQuery.StreamingDisposition\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13\x43reateQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\".\n\x11\x43reateQueryResult\x12\x19\n\x08query_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x81\x04\n\x12ListQueriesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x36\n\x06\x66ilter\x18\x04 \x01(\x0b\x32&.YandexQuery.ListQueriesRequest.Filter\x1a\xbd\x02\n\x06\x46ilter\x12\x37\n\nquery_type\x18\x01 \x01(\x0e\x32#.YandexQuery.QueryContent.QueryType\x12<\n\x06status\x18\x02 \x03(\x0e\x32$.YandexQuery.QueryMeta.ComputeStatusB\x06\x9a\xe6*\x02\x18\x14\x12.\n\x04mode\x18\x03 \x03(\x0e\x32\x18.YandexQuery.ExecuteModeB\x06\x9a\xe6*\x02\x18\x14\x12\x15\n\x04name\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x05 \x01(\x08\x12/\n\nvisibility\x18\x06 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\x12-\n\tautomatic\x18\x07 \x01(\x0e\x32\x1a.YandexQuery.AutomaticType\"C\n\x13ListQueriesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x11ListQueriesResult\x12&\n\x05query\x18\x01 \x03(\x0b\x32\x17.YandexQuery.BriefQuery\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"p\n\x14\x44\x65scribeQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"E\n\x15\x44\x65scribeQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"8\n\x13\x44\x65scribeQueryResult\x12!\n\x05query\x18\x01 \x01(\x0b\x32\x12.YandexQuery.Query\"q\n\x15GetQueryStatusRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"F\n\x16GetQueryStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"c\n\x14GetQueryStatusResult\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.YandexQuery.QueryMeta.ComputeStatus\x12\x15\n\rmeta_revision\x18\x02 \x01(\x03\"\xb5\x01\n\x12\x44\x65leteQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13\x44\x65leteQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x44\x65leteQueryResult\"\xfe\x02\n\x12ModifyQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12*\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x19.YandexQuery.QueryContent\x12.\n\x0c\x65xecute_mode\x18\x04 \x01(\x0e\x32\x18.YandexQuery.ExecuteMode\x12\x36\n\x0b\x64isposition\x18\x05 \x01(\x0b\x32!.YandexQuery.StreamingDisposition\x12\x33\n\x0fstate_load_mode\x18\x06 \x01(\x0e\x32\x1a.YandexQuery.StateLoadMode\x12#\n\x11previous_revision\x18\x07 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13ModifyQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11ModifyQueryResult\"\xe0\x01\n\x13\x43ontrolQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12(\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x18.YandexQuery.QueryAction\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"D\n\x14\x43ontrolQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43ontrolQueryResult\"\xe4\x01\n\x08\x42riefJob\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\x12*\n\nquery_meta\x18\x03 \x01(\x0b\x32\x16.YandexQuery.QueryMeta\x12\x12\n\nquery_name\x18\t \x01(\t\x12/\n\nvisibility\x18\n \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x12-\n\texpire_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xeb\x03\n\x03Job\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\x12\x0c\n\x04text\x18\x02 \x01(\t\x12*\n\nquery_meta\x18\x03 \x01(\x0b\x32\x16.YandexQuery.QueryMeta\x12$\n\x04plan\x18\x04 \x01(\x0b\x32\x16.YandexQuery.QueryPlan\x12&\n\x05issue\x18\x05 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\nstatistics\x18\x06 \x01(\x0b\x32\x1c.YandexQuery.QueryStatistics\x12\x33\n\x0fresult_set_meta\x18\x07 \x03(\x0b\x32\x1a.YandexQuery.ResultSetMeta\x12\"\n\x03\x61st\x18\x08 \x01(\x0b\x32\x15.YandexQuery.QueryAst\x12\x12\n\nquery_name\x18\t \x01(\t\x12\x1d\n\x03\x61\x63l\x18\n \x01(\x0b\x32\x10.YandexQuery.Acl\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x12-\n\texpire_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x06syntax\x18\r \x01(\x0e\x32%.YandexQuery.QueryContent.QuerySyntax\"\x89\x02\n\x0fListJobsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x10\n\x08query_id\x18\x05 \x01(\t\x12\x33\n\x06\x66ilter\x18\x04 \x01(\x0b\x32#.YandexQuery.ListJobsRequest.Filter\x1a:\n\x06\x46ilter\x12\x19\n\x08query_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x02 \x01(\x08\"@\n\x10ListJobsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"V\n\x0eListJobsResult\x12\"\n\x03job\x18\x01 \x03(\x0b\x32\x15.YandexQuery.BriefJob\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"l\n\x12\x44\x65scribeJobRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\x06job_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"C\n\x13\x44\x65scribeJobResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"2\n\x11\x44\x65scribeJobResult\x12\x1d\n\x03job\x18\x01 \x01(\x0b\x32\x10.YandexQuery.Job\"\x15\n\x13\x43urrentIAMTokenAuth\"\n\n\x08NoneAuth\")\n\x12ServiceAccountAuth\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\xb1\x01\n\x07IamAuth\x12\x37\n\x0b\x63urrent_iam\x18\x01 \x01(\x0b\x32 .YandexQuery.CurrentIAMTokenAuthH\x00\x12:\n\x0fservice_account\x18\x02 \x01(\x0b\x32\x1f.YandexQuery.ServiceAccountAuthH\x00\x12%\n\x04none\x18\x03 \x01(\x0b\x32\x15.YandexQuery.NoneAuthH\x00\x42\n\n\x08identity\"\x95\x01\n\x0b\x44\x61taStreams\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.YandexQuery.IamAuth\x12\x19\n\x08\x65ndpoint\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x08\x64\x61tabase\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x0e\n\x06secure\x18\x05 \x01(\x08\"d\n\nMonitoring\x12\x18\n\x07project\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\xc8\x01\x12\x18\n\x07\x63luster\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\xc8\x01\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.YandexQuery.IamAuth\"\x95\x01\n\x0bYdbDatabase\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.YandexQuery.IamAuth\x12\x19\n\x08\x65ndpoint\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x08\x64\x61tabase\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x0e\n\x06secure\x18\x05 \x01(\x08\"\xd5\x01\n\x11\x43lickHouseCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x02 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.YandexQuery.IamAuth\x12\x15\n\x04host\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x04port\x18\x06 \x01(\x05\x42\x0e\xb2\xe6*\n[0; 65536]\x12\x0e\n\x06secure\x18\x07 \x01(\x08\"V\n\x17ObjectStorageConnection\x12\x17\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.YandexQuery.IamAuth\"\xc6\x03\n\x11\x43onnectionSetting\x12\x30\n\x0cydb_database\x18\x01 \x01(\x0b\x32\x18.YandexQuery.YdbDatabaseH\x00\x12<\n\x12\x63lickhouse_cluster\x18\x02 \x01(\x0b\x32\x1e.YandexQuery.ClickHouseClusterH\x00\x12\x30\n\x0c\x64\x61ta_streams\x18\x03 \x01(\x0b\x32\x18.YandexQuery.DataStreamsH\x00\x12>\n\x0eobject_storage\x18\x04 \x01(\x0b\x32$.YandexQuery.ObjectStorageConnectionH\x00\x12-\n\nmonitoring\x18\x05 \x01(\x0b\x32\x17.YandexQuery.MonitoringH\x00\"\x91\x01\n\x0e\x43onnectionType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cYDB_DATABASE\x10\x01\x12\x16\n\x12\x43LICKHOUSE_CLUSTER\x10\x02\x12\x10\n\x0c\x44\x41TA_STREAMS\x10\x03\x12\x12\n\x0eOBJECT_STORAGE\x10\x04\x12\x0e\n\nMONITORING\x10\x05\x42\x0c\n\nconnection\"\x9c\x01\n\x11\x43onnectionContent\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12/\n\x07setting\x18\x02 \x01(\x0b\x32\x1e.YandexQuery.ConnectionSetting\x12\x1d\n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x10.YandexQuery.Acl\x12\x1c\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\"d\n\nConnection\x12/\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1e.YandexQuery.ConnectionContent\x12%\n\x04meta\x18\x02 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\"\xa7\x01\n\x17\x43reateConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12/\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1e.YandexQuery.ConnectionContent\x12 \n\x0fidempotency_key\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18\x43reateConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"<\n\x16\x43reateConnectionResult\x12\"\n\rconnection_id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"\xfb\x02\n\x16ListConnectionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.YandexQuery.ListConnectionsRequest.Filter\x1a\xaf\x01\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x02 \x01(\x08\x12\x46\n\x0f\x63onnection_type\x18\x03 \x01(\x0e\x32-.YandexQuery.ConnectionSetting.ConnectionType\x12/\n\nvisibility\x18\x04 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\"G\n\x17ListConnectionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"f\n\x15ListConnectionsResult\x12+\n\nconnection\x18\x01 \x03(\x0b\x32\x17.YandexQuery.Connection\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"z\n\x19\x44\x65scribeConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"J\n\x1a\x44\x65scribeConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"G\n\x18\x44\x65scribeConnectionResult\x12+\n\nconnection\x18\x01 \x01(\x0b\x32\x17.YandexQuery.Connection\"\xf0\x01\n\x17ModifyConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12/\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1e.YandexQuery.ConnectionContent\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18ModifyConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16ModifyConnectionResult\"\xbf\x01\n\x17\x44\x65leteConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18\x44\x65leteConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16\x44\x65leteConnectionResult\"\x83\x01\n\x15TestConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12/\n\x07setting\x18\x02 \x01(\x0b\x32\x1e.YandexQuery.ConnectionSetting\"F\n\x16TestConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x16\n\x14TestConnectionResult\"\xcc\x01\n\x14GetResultDataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\x10result_set_index\x18\x03 \x01(\x05\x42\x08\xb2\xe6*\x04>= 0\x12\x18\n\x06offset\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1c\n\x05limit\x18\x05 \x01(\x03\x42\r\xb2\xe6*\t[1; 1000]\"E\n\x15GetResultDataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"9\n\x13GetResultDataResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\"-\n\x06Schema\x12#\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x0b.Ydb.ColumnB\x06\x9a\xe6*\x02\x18\x64\"\x9c\x02\n\x12\x44\x61taStreamsBinding\x12 \n\x0bstream_name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x17\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x0b\x63ompression\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12#\n\x06schema\x18\x04 \x01(\x0b\x32\x13.YandexQuery.Schema\x12R\n\x0e\x66ormat_setting\x18\x05 \x03(\x0b\x32\x32.YandexQuery.DataStreamsBinding.FormatSettingEntryB\x06\x9a\xe6*\x02\x18\x64\x1a\x34\n\x12\x46ormatSettingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x04\n\x14ObjectStorageBinding\x12\x38\n\x06subset\x18\x01 \x03(\x0b\x32(.YandexQuery.ObjectStorageBinding.Subset\x1a\xb3\x03\n\x06Subset\x12!\n\x0cpath_pattern\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x17\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12[\n\x0e\x66ormat_setting\x18\x03 \x03(\x0b\x32;.YandexQuery.ObjectStorageBinding.Subset.FormatSettingEntryB\x06\x9a\xe6*\x02\x18\x64\x12\x1c\n\x0b\x63ompression\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12#\n\x06schema\x18\x05 \x01(\x0b\x32\x13.YandexQuery.Schema\x12L\n\nprojection\x18\x06 \x03(\x0b\x32\x38.YandexQuery.ObjectStorageBinding.Subset.ProjectionEntry\x12\x16\n\x0epartitioned_by\x18\x07 \x03(\t\x1a\x34\n\x12\x46ormatSettingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fProjectionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe4\x01\n\x0e\x42indingSetting\x12\x37\n\x0c\x64\x61ta_streams\x18\x01 \x01(\x0b\x32\x1f.YandexQuery.DataStreamsBindingH\x00\x12;\n\x0eobject_storage\x18\x02 \x01(\x0b\x32!.YandexQuery.ObjectStorageBindingH\x00\"Q\n\x0b\x42indingType\x12\x1c\n\x18\x42INDING_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x44\x41TA_STREAMS\x10\x01\x12\x12\n\x0eOBJECT_STORAGE\x10\x02\x42\t\n\x07\x62inding\"\xdc\x01\n\x0c\x42riefBinding\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12%\n\x04meta\x18\x03 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\x12\x35\n\x04type\x18\x04 \x01(\x0e\x32\'.YandexQuery.BindingSetting.BindingType\x12/\n\nvisibility\x18\x05 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\"\xba\x01\n\x0e\x42indingContent\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12,\n\x07setting\x18\x03 \x01(\x0b\x32\x1b.YandexQuery.BindingSetting\x12\x1d\n\x03\x61\x63l\x18\x04 \x01(\x0b\x32\x10.YandexQuery.Acl\x12\x1c\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\"^\n\x07\x42inding\x12,\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1b.YandexQuery.BindingContent\x12%\n\x04meta\x18\x02 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\"\xa1\x01\n\x14\x43reateBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12,\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1b.YandexQuery.BindingContent\x12 \n\x0fidempotency_key\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15\x43reateBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"6\n\x13\x43reateBindingResult\x12\x1f\n\nbinding_id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"\xcd\x02\n\x13ListBindingsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x37\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\'.YandexQuery.ListBindingsRequest.Filter\x1a\x87\x01\n\x06\x46ilter\x12\x1e\n\rconnection_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x03 \x01(\x08\x12/\n\nvisibility\x18\x04 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\"D\n\x14ListBindingsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"b\n\x12ListBindingsResult\x12*\n\x07\x62inding\x18\x01 \x03(\x0b\x32\x19.YandexQuery.BriefBinding\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"t\n\x16\x44\x65scribeBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"G\n\x17\x44\x65scribeBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\">\n\x15\x44\x65scribeBindingResult\x12%\n\x07\x62inding\x18\x01 \x01(\x0b\x32\x14.YandexQuery.Binding\"\xe7\x01\n\x14ModifyBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12,\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1b.YandexQuery.BindingContent\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15ModifyBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13ModifyBindingResult\"\xb9\x01\n\x14\x44\x65leteBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15\x44\x65leteBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13\x44\x65leteBindingResult*q\n\x0b\x45xecuteMode\x12\x1c\n\x18\x45XECUTE_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAVE\x10\x01\x12\t\n\x05PARSE\x10\x02\x12\x0b\n\x07\x43OMPILE\x10\x03\x12\x0c\n\x08VALIDATE\x10\x04\x12\x0b\n\x07\x45XPLAIN\x10\x05\x12\x07\n\x03RUN\x10\x06*y\n\x0bQueryAction\x12\x1c\n\x18QUERY_ACTION_UNSPECIFIED\x10\x00\x12\t\n\x05PAUSE\x10\x01\x12\x14\n\x10PAUSE_GRACEFULLY\x10\x02\x12\t\n\x05\x41\x42ORT\x10\x03\x12\x14\n\x10\x41\x42ORT_GRACEFULLY\x10\x04\x12\n\n\x06RESUME\x10\x05*U\n\rStateLoadMode\x12\x1f\n\x1bSTATE_LOAD_MODE_UNSPECIFIED\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x18\n\x14\x46ROM_LAST_CHECKPOINT\x10\x02*Q\n\rAutomaticType\x12\x1e\n\x1a\x41UTOMATIC_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tAUTOMATIC\x10\x01\x12\x11\n\rNOT_AUTOMATIC\x10\x02\x42(\n\x10\x63om.yandex.queryB\x11YandexQueryProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.yq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020com.yandex.queryB\021YandexQueryProtos\370\001\001'
  _LIMITS.fields_by_name['vcpu_rate_limit']._options = None
  _LIMITS.fields_by_name['vcpu_rate_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['flow_rate_limit']._options = None
  _LIMITS.fields_by_name['flow_rate_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['vcpu_time_limit']._options = None
  _LIMITS.fields_by_name['vcpu_time_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['max_result_size']._options = None
  _LIMITS.fields_by_name['max_result_size']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['max_result_rows']._options = None
  _LIMITS.fields_by_name['max_result_rows']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['memory_limit']._options = None
  _LIMITS.fields_by_name['memory_limit']._serialized_options = b'\262\346*\004>= 0'
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._options = None
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_options = b'8\001'
  _QUERYCONTENT.fields_by_name['name']._options = None
  _QUERYCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _QUERYCONTENT.fields_by_name['text']._options = None
  _QUERYCONTENT.fields_by_name['text']._serialized_options = b'\242\346*\004\030\200\240\006'
  _QUERYCONTENT.fields_by_name['description']._options = None
  _QUERYCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _QUERYCONTENT.fields_by_name['execution_settings']._options = None
  _QUERYCONTENT.fields_by_name['execution_settings']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\003\030\200 '
  _COMMONMETA.fields_by_name['id']._options = None
  _COMMONMETA.fields_by_name['id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['created_by']._options = None
  _COMMONMETA.fields_by_name['created_by']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['modified_by']._options = None
  _COMMONMETA.fields_by_name['modified_by']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['revision']._options = None
  _COMMONMETA.fields_by_name['revision']._serialized_options = b'\262\346*\004>= 0'
  _BRIEFQUERY.fields_by_name['name']._options = None
  _BRIEFQUERY.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _RESULTSETMETA.fields_by_name['rows_count']._options = None
  _RESULTSETMETA.fields_by_name['rows_count']._serialized_options = b'\262\346*\004>= 0'
  _CREATEQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATEQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATEQUERYRESULT.fields_by_name['query_id']._options = None
  _CREATEQUERYRESULT.fields_by_name['query_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['status']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['status']._serialized_options = b'\232\346*\002\030\024'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['mode']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['mode']._serialized_options = b'\232\346*\002\030\024'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST.fields_by_name['page_token']._options = None
  _LISTQUERIESREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST.fields_by_name['limit']._options = None
  _LISTQUERIESREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTQUERIESRESULT.fields_by_name['next_page_token']._options = None
  _LISTQUERIESRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEQUERYREQUEST.fields_by_name['query_id']._options = None
  _DESCRIBEQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _GETQUERYSTATUSREQUEST.fields_by_name['query_id']._options = None
  _GETQUERYSTATUSREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEQUERYREQUEST.fields_by_name['query_id']._options = None
  _DELETEQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _DELETEQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETEQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETEQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _MODIFYQUERYREQUEST.fields_by_name['query_id']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CONTROLQUERYREQUEST.fields_by_name['query_id']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _CONTROLQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _CONTROLQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTJOBSREQUEST_FILTER.fields_by_name['query_id']._options = None
  _LISTJOBSREQUEST_FILTER.fields_by_name['query_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTJOBSREQUEST.fields_by_name['page_token']._options = None
  _LISTJOBSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTJOBSREQUEST.fields_by_name['limit']._options = None
  _LISTJOBSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTJOBSRESULT.fields_by_name['next_page_token']._options = None
  _LISTJOBSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEJOBREQUEST.fields_by_name['job_id']._options = None
  _DESCRIBEJOBREQUEST.fields_by_name['job_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _SERVICEACCOUNTAUTH.fields_by_name['id']._options = None
  _SERVICEACCOUNTAUTH.fields_by_name['id']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMS.fields_by_name['database_id']._options = None
  _DATASTREAMS.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMS.fields_by_name['endpoint']._options = None
  _DATASTREAMS.fields_by_name['endpoint']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMS.fields_by_name['database']._options = None
  _DATASTREAMS.fields_by_name['database']._serialized_options = b'\242\346*\003\030\200\010'
  _MONITORING.fields_by_name['project']._options = None
  _MONITORING.fields_by_name['project']._serialized_options = b'\242\346*\003\030\310\001'
  _MONITORING.fields_by_name['cluster']._options = None
  _MONITORING.fields_by_name['cluster']._serialized_options = b'\242\346*\003\030\310\001'
  _YDBDATABASE.fields_by_name['database_id']._options = None
  _YDBDATABASE.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _YDBDATABASE.fields_by_name['endpoint']._options = None
  _YDBDATABASE.fields_by_name['endpoint']._serialized_options = b'\242\346*\003\030\200\010'
  _YDBDATABASE.fields_by_name['database']._options = None
  _YDBDATABASE.fields_by_name['database']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['database_id']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['login']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['login']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _CLICKHOUSECLUSTER.fields_by_name['password']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['password']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _CLICKHOUSECLUSTER.fields_by_name['host']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['host']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['port']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['port']._serialized_options = b'\262\346*\n[0; 65536]'
  _OBJECTSTORAGECONNECTION.fields_by_name['bucket']._options = None
  _OBJECTSTORAGECONNECTION.fields_by_name['bucket']._serialized_options = b'\242\346*\003\030\200\010'
  _CONNECTIONCONTENT.fields_by_name['name']._options = None
  _CONNECTIONCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _CONNECTIONCONTENT.fields_by_name['description']._options = None
  _CONNECTIONCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _CREATECONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATECONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATECONNECTIONRESULT.fields_by_name['connection_id']._options = None
  _CREATECONNECTIONRESULT.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _LISTCONNECTIONSREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTCONNECTIONSREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTCONNECTIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTCONNECTIONSREQUEST.fields_by_name['limit']._options = None
  _LISTCONNECTIONSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTCONNECTIONSRESULT.fields_by_name['next_page_token']._options = None
  _LISTCONNECTIONSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DESCRIBECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYCONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYCONNECTIONREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYCONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _DELETECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETECONNECTIONREQUEST.fields_by_name['previous_revision']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETECONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _GETRESULTDATAREQUEST.fields_by_name['query_id']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _GETRESULTDATAREQUEST.fields_by_name['result_set_index']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['result_set_index']._serialized_options = b'\262\346*\004>= 0'
  _GETRESULTDATAREQUEST.fields_by_name['offset']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['offset']._serialized_options = b'\262\346*\004>= 0'
  _GETRESULTDATAREQUEST.fields_by_name['limit']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\t[1; 1000]'
  _SCHEMA.fields_by_name['column']._options = None
  _SCHEMA.fields_by_name['column']._serialized_options = b'\232\346*\002\030d'
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._options = None
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_options = b'8\001'
  _DATASTREAMSBINDING.fields_by_name['stream_name']._options = None
  _DATASTREAMSBINDING.fields_by_name['stream_name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DATASTREAMSBINDING.fields_by_name['format']._options = None
  _DATASTREAMSBINDING.fields_by_name['format']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMSBINDING.fields_by_name['compression']._options = None
  _DATASTREAMSBINDING.fields_by_name['compression']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMSBINDING.fields_by_name['format_setting']._options = None
  _DATASTREAMSBINDING.fields_by_name['format_setting']._serialized_options = b'\232\346*\002\030d'
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._options = None
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_options = b'8\001'
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._options = None
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_options = b'8\001'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['path_pattern']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['path_pattern']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format']._serialized_options = b'\242\346*\003\030\200\010'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format_setting']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format_setting']._serialized_options = b'\232\346*\002\030d'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['compression']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['compression']._serialized_options = b'\242\346*\003\030\200\010'
  _BRIEFBINDING.fields_by_name['name']._options = None
  _BRIEFBINDING.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BRIEFBINDING.fields_by_name['connection_id']._options = None
  _BRIEFBINDING.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['name']._options = None
  _BINDINGCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['connection_id']._options = None
  _BINDINGCONTENT.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['description']._options = None
  _BINDINGCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _CREATEBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATEBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATEBINDINGRESULT.fields_by_name['binding_id']._options = None
  _CREATEBINDINGRESULT.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['connection_id']._options = None
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['connection_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST.fields_by_name['page_token']._options = None
  _LISTBINDINGSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST.fields_by_name['limit']._options = None
  _LISTBINDINGSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTBINDINGSRESULT.fields_by_name['next_page_token']._options = None
  _LISTBINDINGSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _DESCRIBEBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYBINDINGREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _DELETEBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEBINDINGREQUEST.fields_by_name['previous_revision']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETEBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTEMODE._serialized_start=15068
  _EXECUTEMODE._serialized_end=15181
  _QUERYACTION._serialized_start=15183
  _QUERYACTION._serialized_end=15304
  _STATELOADMODE._serialized_start=15306
  _STATELOADMODE._serialized_end=15391
  _AUTOMATICTYPE._serialized_start=15393
  _AUTOMATICTYPE._serialized_end=15474
  _ACL._serialized_start=373
  _ACL._serialized_end=493
  _ACL_VISIBILITY._serialized_start=429
  _ACL_VISIBILITY._serialized_end=493
  _LIMITS._serialized_start=496
  _LIMITS._serialized_end=883
  _STREAMINGDISPOSITION._serialized_start=886
  _STREAMINGDISPOSITION._serialized_end=1372
  _STREAMINGDISPOSITION_FROMTIME._serialized_start=1207
  _STREAMINGDISPOSITION_FROMTIME._serialized_end=1264
  _STREAMINGDISPOSITION_TIMEAGO._serialized_start=1266
  _STREAMINGDISPOSITION_TIMEAGO._serialized_end=1320
  _STREAMINGDISPOSITION_FROMLASTCHECKPOINT._serialized_start=1322
  _STREAMINGDISPOSITION_FROMLASTCHECKPOINT._serialized_end=1357
  _QUERYCONTENT._serialized_start=1375
  _QUERYCONTENT._serialized_end=1952
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_start=1760
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_end=1816
  _QUERYCONTENT_QUERYTYPE._serialized_start=1818
  _QUERYCONTENT_QUERYTYPE._serialized_end=1887
  _QUERYCONTENT_QUERYSYNTAX._serialized_start=1889
  _QUERYCONTENT_QUERYSYNTAX._serialized_end=1952
  _COMMONMETA._serialized_start=1955
  _COMMONMETA._serialized_end=2184
  _QUERYMETA._serialized_start=2187
  _QUERYMETA._serialized_end=3009
  _QUERYMETA_COMPUTESTATUS._serialized_start=2740
  _QUERYMETA_COMPUTESTATUS._serialized_end=2999
  _BRIEFQUERY._serialized_start=3012
  _BRIEFQUERY._serialized_end=3204
  _QUERYPLAN._serialized_start=3206
  _QUERYPLAN._serialized_end=3231
  _QUERYAST._serialized_start=3233
  _QUERYAST._serialized_end=3257
  _RESULTSETMETA._serialized_start=3259
  _RESULTSETMETA._serialized_end=3352
  _QUERY._serialized_start=3355
  _QUERY._serialized_end=3711
  _QUERYSTATISTICS._serialized_start=3713
  _QUERYSTATISTICS._serialized_end=3744
  _CREATEQUERYREQUEST._serialized_start=3747
  _CREATEQUERYREQUEST._serialized_end=4008
  _CREATEQUERYRESPONSE._serialized_start=4010
  _CREATEQUERYRESPONSE._serialized_end=4077
  _CREATEQUERYRESULT._serialized_start=4079
  _CREATEQUERYRESULT._serialized_end=4125
  _LISTQUERIESREQUEST._serialized_start=4128
  _LISTQUERIESREQUEST._serialized_end=4641
  _LISTQUERIESREQUEST_FILTER._serialized_start=4324
  _LISTQUERIESREQUEST_FILTER._serialized_end=4641
  _LISTQUERIESRESPONSE._serialized_start=4643
  _LISTQUERIESRESPONSE._serialized_end=4710
  _LISTQUERIESRESULT._serialized_start=4712
  _LISTQUERIESRESULT._serialized_end=4805
  _DESCRIBEQUERYREQUEST._serialized_start=4807
  _DESCRIBEQUERYREQUEST._serialized_end=4919
  _DESCRIBEQUERYRESPONSE._serialized_start=4921
  _DESCRIBEQUERYRESPONSE._serialized_end=4990
  _DESCRIBEQUERYRESULT._serialized_start=4992
  _DESCRIBEQUERYRESULT._serialized_end=5048
  _GETQUERYSTATUSREQUEST._serialized_start=5050
  _GETQUERYSTATUSREQUEST._serialized_end=5163
  _GETQUERYSTATUSRESPONSE._serialized_start=5165
  _GETQUERYSTATUSRESPONSE._serialized_end=5235
  _GETQUERYSTATUSRESULT._serialized_start=5237
  _GETQUERYSTATUSRESULT._serialized_end=5336
  _DELETEQUERYREQUEST._serialized_start=5339
  _DELETEQUERYREQUEST._serialized_end=5520
  _DELETEQUERYRESPONSE._serialized_start=5522
  _DELETEQUERYRESPONSE._serialized_end=5589
  _DELETEQUERYRESULT._serialized_start=5591
  _DELETEQUERYRESULT._serialized_end=5610
  _MODIFYQUERYREQUEST._serialized_start=5613
  _MODIFYQUERYREQUEST._serialized_end=5995
  _MODIFYQUERYRESPONSE._serialized_start=5997
  _MODIFYQUERYRESPONSE._serialized_end=6064
  _MODIFYQUERYRESULT._serialized_start=6066
  _MODIFYQUERYRESULT._serialized_end=6085
  _CONTROLQUERYREQUEST._serialized_start=6088
  _CONTROLQUERYREQUEST._serialized_end=6312
  _CONTROLQUERYRESPONSE._serialized_start=6314
  _CONTROLQUERYRESPONSE._serialized_end=6382
  _CONTROLQUERYRESULT._serialized_start=6384
  _CONTROLQUERYRESULT._serialized_end=6404
  _BRIEFJOB._serialized_start=6407
  _BRIEFJOB._serialized_end=6635
  _JOB._serialized_start=6638
  _JOB._serialized_end=7129
  _LISTJOBSREQUEST._serialized_start=7132
  _LISTJOBSREQUEST._serialized_end=7397
  _LISTJOBSREQUEST_FILTER._serialized_start=7339
  _LISTJOBSREQUEST_FILTER._serialized_end=7397
  _LISTJOBSRESPONSE._serialized_start=7399
  _LISTJOBSRESPONSE._serialized_end=7463
  _LISTJOBSRESULT._serialized_start=7465
  _LISTJOBSRESULT._serialized_end=7551
  _DESCRIBEJOBREQUEST._serialized_start=7553
  _DESCRIBEJOBREQUEST._serialized_end=7661
  _DESCRIBEJOBRESPONSE._serialized_start=7663
  _DESCRIBEJOBRESPONSE._serialized_end=7730
  _DESCRIBEJOBRESULT._serialized_start=7732
  _DESCRIBEJOBRESULT._serialized_end=7782
  _CURRENTIAMTOKENAUTH._serialized_start=7784
  _CURRENTIAMTOKENAUTH._serialized_end=7805
  _NONEAUTH._serialized_start=7807
  _NONEAUTH._serialized_end=7817
  _SERVICEACCOUNTAUTH._serialized_start=7819
  _SERVICEACCOUNTAUTH._serialized_end=7860
  _IAMAUTH._serialized_start=7863
  _IAMAUTH._serialized_end=8040
  _DATASTREAMS._serialized_start=8043
  _DATASTREAMS._serialized_end=8192
  _MONITORING._serialized_start=8194
  _MONITORING._serialized_end=8294
  _YDBDATABASE._serialized_start=8297
  _YDBDATABASE._serialized_end=8446
  _CLICKHOUSECLUSTER._serialized_start=8449
  _CLICKHOUSECLUSTER._serialized_end=8662
  _OBJECTSTORAGECONNECTION._serialized_start=8664
  _OBJECTSTORAGECONNECTION._serialized_end=8750
  _CONNECTIONSETTING._serialized_start=8753
  _CONNECTIONSETTING._serialized_end=9207
  _CONNECTIONSETTING_CONNECTIONTYPE._serialized_start=9048
  _CONNECTIONSETTING_CONNECTIONTYPE._serialized_end=9193
  _CONNECTIONCONTENT._serialized_start=9210
  _CONNECTIONCONTENT._serialized_end=9366
  _CONNECTION._serialized_start=9368
  _CONNECTION._serialized_end=9468
  _CREATECONNECTIONREQUEST._serialized_start=9471
  _CREATECONNECTIONREQUEST._serialized_end=9638
  _CREATECONNECTIONRESPONSE._serialized_start=9640
  _CREATECONNECTIONRESPONSE._serialized_end=9712
  _CREATECONNECTIONRESULT._serialized_start=9714
  _CREATECONNECTIONRESULT._serialized_end=9774
  _LISTCONNECTIONSREQUEST._serialized_start=9777
  _LISTCONNECTIONSREQUEST._serialized_end=10156
  _LISTCONNECTIONSREQUEST_FILTER._serialized_start=9981
  _LISTCONNECTIONSREQUEST_FILTER._serialized_end=10156
  _LISTCONNECTIONSRESPONSE._serialized_start=10158
  _LISTCONNECTIONSRESPONSE._serialized_end=10229
  _LISTCONNECTIONSRESULT._serialized_start=10231
  _LISTCONNECTIONSRESULT._serialized_end=10333
  _DESCRIBECONNECTIONREQUEST._serialized_start=10335
  _DESCRIBECONNECTIONREQUEST._serialized_end=10457
  _DESCRIBECONNECTIONRESPONSE._serialized_start=10459
  _DESCRIBECONNECTIONRESPONSE._serialized_end=10533
  _DESCRIBECONNECTIONRESULT._serialized_start=10535
  _DESCRIBECONNECTIONRESULT._serialized_end=10606
  _MODIFYCONNECTIONREQUEST._serialized_start=10609
  _MODIFYCONNECTIONREQUEST._serialized_end=10849
  _MODIFYCONNECTIONRESPONSE._serialized_start=10851
  _MODIFYCONNECTIONRESPONSE._serialized_end=10923
  _MODIFYCONNECTIONRESULT._serialized_start=10925
  _MODIFYCONNECTIONRESULT._serialized_end=10949
  _DELETECONNECTIONREQUEST._serialized_start=10952
  _DELETECONNECTIONREQUEST._serialized_end=11143
  _DELETECONNECTIONRESPONSE._serialized_start=11145
  _DELETECONNECTIONRESPONSE._serialized_end=11217
  _DELETECONNECTIONRESULT._serialized_start=11219
  _DELETECONNECTIONRESULT._serialized_end=11243
  _TESTCONNECTIONREQUEST._serialized_start=11246
  _TESTCONNECTIONREQUEST._serialized_end=11377
  _TESTCONNECTIONRESPONSE._serialized_start=11379
  _TESTCONNECTIONRESPONSE._serialized_end=11449
  _TESTCONNECTIONRESULT._serialized_start=11451
  _TESTCONNECTIONRESULT._serialized_end=11473
  _GETRESULTDATAREQUEST._serialized_start=11476
  _GETRESULTDATAREQUEST._serialized_end=11680
  _GETRESULTDATARESPONSE._serialized_start=11682
  _GETRESULTDATARESPONSE._serialized_end=11751
  _GETRESULTDATARESULT._serialized_start=11753
  _GETRESULTDATARESULT._serialized_end=11810
  _SCHEMA._serialized_start=11812
  _SCHEMA._serialized_end=11857
  _DATASTREAMSBINDING._serialized_start=11860
  _DATASTREAMSBINDING._serialized_end=12144
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_start=12092
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_end=12144
  _OBJECTSTORAGEBINDING._serialized_start=12147
  _OBJECTSTORAGEBINDING._serialized_end=12665
  _OBJECTSTORAGEBINDING_SUBSET._serialized_start=12230
  _OBJECTSTORAGEBINDING_SUBSET._serialized_end=12665
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_start=12092
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_end=12144
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_start=12616
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_end=12665
  _BINDINGSETTING._serialized_start=12668
  _BINDINGSETTING._serialized_end=12896
  _BINDINGSETTING_BINDINGTYPE._serialized_start=12804
  _BINDINGSETTING_BINDINGTYPE._serialized_end=12885
  _BRIEFBINDING._serialized_start=12899
  _BRIEFBINDING._serialized_end=13119
  _BINDINGCONTENT._serialized_start=13122
  _BINDINGCONTENT._serialized_end=13308
  _BINDING._serialized_start=13310
  _BINDING._serialized_end=13404
  _CREATEBINDINGREQUEST._serialized_start=13407
  _CREATEBINDINGREQUEST._serialized_end=13568
  _CREATEBINDINGRESPONSE._serialized_start=13570
  _CREATEBINDINGRESPONSE._serialized_end=13639
  _CREATEBINDINGRESULT._serialized_start=13641
  _CREATEBINDINGRESULT._serialized_end=13695
  _LISTBINDINGSREQUEST._serialized_start=13698
  _LISTBINDINGSREQUEST._serialized_end=14031
  _LISTBINDINGSREQUEST_FILTER._serialized_start=13896
  _LISTBINDINGSREQUEST_FILTER._serialized_end=14031
  _LISTBINDINGSRESPONSE._serialized_start=14033
  _LISTBINDINGSRESPONSE._serialized_end=14101
  _LISTBINDINGSRESULT._serialized_start=14103
  _LISTBINDINGSRESULT._serialized_end=14201
  _DESCRIBEBINDINGREQUEST._serialized_start=14203
  _DESCRIBEBINDINGREQUEST._serialized_end=14319
  _DESCRIBEBINDINGRESPONSE._serialized_start=14321
  _DESCRIBEBINDINGRESPONSE._serialized_end=14392
  _DESCRIBEBINDINGRESULT._serialized_start=14394
  _DESCRIBEBINDINGRESULT._serialized_end=14456
  _MODIFYBINDINGREQUEST._serialized_start=14459
  _MODIFYBINDINGREQUEST._serialized_end=14690
  _MODIFYBINDINGRESPONSE._serialized_start=14692
  _MODIFYBINDINGRESPONSE._serialized_end=14761
  _MODIFYBINDINGRESULT._serialized_start=14763
  _MODIFYBINDINGRESULT._serialized_end=14784
  _DELETEBINDINGREQUEST._serialized_start=14787
  _DELETEBINDINGREQUEST._serialized_end=14972
  _DELETEBINDINGRESPONSE._serialized_start=14974
  _DELETEBINDINGRESPONSE._serialized_end=15043
  _DELETEBINDINGRESULT._serialized_start=15045
  _DELETEBINDINGRESULT._serialized_end=15066
# @@protoc_insertion_point(module_scope)
